@@ -180,7 +180,8 @@ class Tap(ArgumentParser):
                 ):
                     var_type, kwargs['choices'] = get_literals(get_args(var_type)[0], variable)
                 elif var_type not in SUPPORTED_DEFAULT_TYPES:
-                    arg_params = "required=True" if kwargs["required"] else f"default={getattr(self, variable)}"
+                    is_required = kwargs.get('required', False)
+                    arg_params = 'required=True' if is_required else f'default={getattr(self, variable)}'
                     raise ValueError(
                         f'Variable "{variable}" has type "{var_type}" which is not supported by default.\n'
                         f'Please explicitly add the argument to the parser by writing:\n\n'
@@ -309,12 +310,13 @@ class Tap(ArgumentParser):
         for variable, value in vars(default_namespace).items():
             # Conversion from list to set or tuple
             if variable in self._annotations:
-                var_type = get_origin(self._annotations[variable])
+                if type(value) == list:
+                    var_type = get_origin(self._annotations[variable])
 
-                if var_type in (Set, set):
-                    value = set(value)
-                elif var_type in (Tuple, tuple):
-                    value = tuple(value)
+                    if var_type in (Set, set):
+                        value = set(value)
+                    elif var_type in (Tuple, tuple):
+                        value = tuple(value)
 
             # Set variable in self (and deepcopy)
             setattr(self, variable, deepcopy(value))
@@ -451,12 +453,13 @@ class Tap(ArgumentParser):
 
         return stored_dict
 
-    def from_dict(self, args_dict: Dict[str, Any], skip_unsettable: bool = False) -> None:
+    def from_dict(self, args_dict: Dict[str, Any], skip_unsettable: bool = False) -> TapType:
         """Loads arguments from a dictionary, ensuring all required arguments are set.
 
         :param args_dict: A dictionary from argument names to the values of the arguments.
         :param skip_unsettable: When True, skips attributes that cannot be set in the Tap object,
                                 e.g. properties without setters.
+        :return: Returns self.
         """
         # All of the required arguments must be provided or already set
         required_args = {a.dest for a in self._actions if a.required}
@@ -479,18 +482,23 @@ class Tap(ArgumentParser):
 
         self._parsed = True
 
-    def save(self, path: str) -> None:
+        return self
+
+    def save(self, path: str, with_reproducibility: bool = True) -> None:
         """Saves the arguments and reproducibility information in JSON format, pickling what can't be encoded.
 
         :param path: Path to the JSON file where the arguments will be saved.
+        :param with_reproducibility: If True, adds a "reproducibility" field with information (e.g. git hash)
+                                     to the JSON file.
         """
         with open(path, 'w') as f:
-            json.dump(self._log_all(), f, indent=4, sort_keys=True, cls=PythonObjectEncoder)
+            args = self._log_all() if with_reproducibility else self.as_dict()
+            json.dump(args, f, indent=4, sort_keys=True, cls=PythonObjectEncoder)
 
     def load(self,
              path: str,
              check_reproducibility: bool = False,
-             skip_unsettable: bool = False) -> None:
+             skip_unsettable: bool = False) -> TapType:
         """Loads the arguments in JSON format. Note: Due to JSON, tuples are loaded as lists.
 
         :param path: Path to the JSON file where the arguments will be loaded from.
@@ -498,6 +506,7 @@ class Tap(ArgumentParser):
                                       information doesn't match the current reproducibility information.
         :param skip_unsettable: When True, skips attributes that cannot be set in the Tap object,
                                 e.g. properties without setters.
+        :return: Returns self.
         """
         with open(path) as f:
             args_dict = json.load(f, object_hook=as_python_object)
@@ -535,6 +544,8 @@ class Tap(ArgumentParser):
 
         self.from_dict(args_dict, skip_unsettable=skip_unsettable)
 
+        return self
+
     def __str__(self) -> str:
         """Returns a string representation of self.
 
